/* Update all chart timeframes of a specified period.
 * NOTE: The script will ignore the chart it is running on because
 * updating the timeframe results in script removal.
 *
 * This content is released under the terms of the MIT license.
 * A copy of this license has been included with this program in LICENSE.txt
 */
#property copyright "Copyright (c) 2015 TradertoolsFX"
#property link      "http://www.tradertools-fx.com"
#property version   "1.00"
#property strict
#property show_inputs

input ENUM_TIMEFRAMES TriggerPeriod = PERIOD_M15; // Timeframe to be updated to the new period.
input ENUM_TIMEFRAMES NewPeriod = PERIOD_H1;
input bool UpdateAll = false; // Ignore first input and update all charts to the new period.

void OnStart()
{
    ENUM_TIMEFRAMES trigger_period = GetNonZeroTimeframe(TriggerPeriod);
    long script_chart_id = ChartID();

    long chart_id = ChartFirst();
    while (chart_id != -1 &&
           !IsStopped()) {
        if (chart_id != script_chart_id && // Skip chart running the script.
                (UpdateAll ||
                ChartPeriod(chart_id) == trigger_period)) {
            ChartSetSymbolPeriod(chart_id, ChartSymbol(chart_id), NewPeriod);
        }

        chart_id = ChartNext(chart_id);
    }
}

ENUM_TIMEFRAMES GetNonZeroTimeframe(ENUM_TIMEFRAMES timeframe)
{
    if (timeframe > 0) {
        return timeframe;
    } else { // PERIOD_CURRENT
        return ChartPeriod(0);
    }
}
